@@ -1,10 +1,10 @@
 package HTTP::Engine::RequestBuilder::CGI;
-use Mouse;
+use Any::Moose;
 
-with $_ for qw(
+with qw(
     HTTP::Engine::Role::RequestBuilder::HTTPBody
     HTTP::Engine::Role::RequestBuilder::ParseEnv
     HTTP::Engine::Role::RequestBuilder
-);
+);    
 
 __PACKAGE__
